//----------------------------------------------------------------------------
// C main line
//----------------------------------------------------------------------------

#include <m8c.h>        // part specific constants and macros
#include "PSoCAPI.h"    // PSoC API definitions for all User Modules

// bitmap data
const BYTE picture_data[] = {
#include "komekame_picture.h"
};

void out_reg(BYTE dat)
{
	PRT0DR = dat;
	// RD=1,WR=0,A0=0,RES=1,CS=0
	PRT2DR = 0b11101001;
	// RD=1,WR=1,A0=0,RES=1,CS=1
	PRT2DR = 0b11111011;	
}

void out_data(BYTE dat)
{
	PRT0DR = dat;
	// RD=1,WR=0,A0=1,RES=1,CS=0
	PRT2DR = 0b11101101;
	// RD=1,WR=1,A0=1,RES=1,CS=1
	PRT2DR = 0b11111111;	
}

void oled_initialize(void)
{
	BYTE i, j;

	/* --- OLED module Initialize */
	out_reg(0xa0); //segment remap
	out_reg(0xda); //common pads hardware: alternative
	out_reg(0x12);
	out_reg(0xc0); //common output scan direction:com0~com127
	out_reg(0xa8); //multiplex ration mode:63
	out_reg(0x3f);
	out_reg(0xd5); //display divide ratio/osc. freq. mode
	out_reg(0x50); //Osc. Freq:5,DivideRation:0
	out_reg(0xdb); //VCOM deselect level mode:64
	out_reg(0x40);
	out_reg(0x81); //contrast control mode:64
	out_reg(0x40);
	out_reg(0xad); //DCDC control mode:off
	out_reg(0x8a);
	
	/* --- screen clear */
	for(i=0; i<8; i++) {
		out_reg(0xb0+ i );
		out_reg(0x02);
		out_reg(0x10);
		for(j=0; j<132; j++) {
			out_data(0);
		}
	}
	
	/* --- module ON */
	out_reg(0xaf); //display on
	LCD_1_Delay50uTimes(200);
	out_reg(0x40); //display start line:0
	out_reg(0xa4); //0xa4:normal display , 0xa5:entire display
	out_reg(0xa6); //0xa6:normal display , 0xa7:reverse display
	out_reg(0xd3); //display offset mode:0
	out_reg(0x00);
	out_reg(0xd9); //discharge / precharge period mode
	out_reg(0x1f); //discharge:1,precharge:0x15
}

void main()
{
	BYTE i, j;
	long count;

	oled_initialize();
	
	/* --- picture transfer */
	count = 0;
	for(i=0; i<8; i++) {
		out_reg(0xb0+i);
		out_reg(0x02);
		out_reg(0x10);
		for(j=0; j<128; j++) {
			out_data( picture_data[count] );
			count += 1;
		}
	}
	
    while(1){
    	/* --- loop */
    }
    
}
